"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.AssertionError = void 0;
const error_stack_parser_1 = __importDefault(require("error-stack-parser"));
/**
 * Assertion error containing optional info about actual / expected value which
 * can be used by test runners like Mocha to pretty print.
 */
class AssertionError extends Error {
    constructor(options) {
        const message = options.message;
        super(message);
        this.name = 'AssertionError';
        this.actual = options.actual;
        this.expected = options.expected;
        this.stack = `${this.message}\n${options.stack}`;
    }
    static getLocation(name) {
        const error = new Error('message');
        let cleaned;
        let parsed;
        return {
            file: () => {
                var _a;
                cleaned = cleaned !== null && cleaned !== void 0 ? cleaned : getCleanStack(error);
                parsed = parsed !== null && parsed !== void 0 ? parsed : error_stack_parser_1.default.parse({ stack: cleaned });
                return (_a = parsed[0]) === null || _a === void 0 ? void 0 : _a.fileName;
            },
            stack: () => {
                cleaned = cleaned !== null && cleaned !== void 0 ? cleaned : getCleanStack(error);
                parsed = parsed !== null && parsed !== void 0 ? parsed : error_stack_parser_1.default.parse({ stack: cleaned });
                return formatStack(name, parsed);
            },
        };
    }
}
exports.AssertionError = AssertionError;
function getCleanStack(error) {
    var _a, _b, _c, _d, _e, _f;
    const lines = (_b = (_a = error.stack) === null || _a === void 0 ? void 0 : _a.split('\n')) !== null && _b !== void 0 ? _b : [];
    if ((_c = lines[0]) === null || _c === void 0 ? void 0 : _c.startsWith('Error: message')) {
        return lines.slice(5).join('\n');
    }
    if (((_d = lines[0]) === null || _d === void 0 ? void 0 : _d.includes('AssertionError')) && ((_e = lines[2]) === null || _e === void 0 ? void 0 : _e.includes('^'))) {
        // in esbuild-register context is added to the stack trace
        return lines.slice(9).join('\n');
    }
    return (_f = error.stack) !== null && _f !== void 0 ? _f : '';
}
function formatStack(name, stack) {
    return stack
        .map((frame, i) => {
        let file = frame.fileName;
        if (file !== undefined && frame.lineNumber !== undefined) {
            file += `:${frame.lineNumber}`;
            if (frame.columnNumber !== undefined) {
                file += `:${frame.columnNumber}`;
            }
        }
        if (i === 0) {
            return file === undefined
                ? `    at ${name}`
                : `    at ${name} (${file})`;
        }
        return frame.source;
    })
        .join('\n');
}
//# sourceMappingURL=AssertionError.js.map