"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.includes = void 0;
const expect_js_1 = require("../../expect.js");
const index_js_1 = require("../../isEqual/index.js");
(0, expect_js_1.registerMatcher)('includes', includes);
function includes(...items) {
    return (value) => {
        if (typeof value === 'string') {
            if (items.some((item) => typeof item !== 'string')) {
                return false;
            }
            return items.every((item) => value.includes(item));
        }
        if (!isIterable(value)) {
            return false;
        }
        return contains(Array.from(value), items);
    };
}
exports.includes = includes;
function isIterable(value) {
    return Symbol.iterator in Object(value);
}
function contains(array, items) {
    const matchedIndexes = {};
    return items.every((expectedItem) => {
        const foundIndex = array.findIndex((actualItem, index) => (0, index_js_1.isEqual)(actualItem, expectedItem) && !matchedIndexes[index]);
        if (foundIndex !== -1) {
            matchedIndexes[foundIndex] = true;
            return true;
        }
        else {
            return false;
        }
    });
}
//# sourceMappingURL=includes.js.map