import { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a number is close to the target value.The range is
         * `[target - delta, target + delta]`, inclusive on both sides.
         *
         * Works only for numbers and not for bigints.
         *
         * If you want to match a nested value, use the matcher
         * `expect.toBeCloseTo(target, delta)` instead.
         *
         * @param target - The number to aim for.
         * @param delta - The maximum difference between the values.
         *
         * @example
         * ```ts
         * expect(0.5).toBeBetween(0, 1)
         * expect(100n).toBeBetween(-200n, 200n)
         *
         * expect(20).not.toBeBetween(0, 1)
         * ```
         */
        toBeCloseTo(this: Validators<number>, target: number, delta: number): void;
    }
}
export declare function toBeCloseTo(control: Control, target: number, delta: number): void;
//# sourceMappingURL=toBeCloseTo.d.ts.map