import { Control } from '../../Control.js';
import { MockFunction } from '../../mocks/index.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that the mock function was called the given number of times.
         *
         * @param times - The number of times the mock function was expected to be
         *   called.
         *
         * @example
         * ```ts
         * import { expect, mockFn } from 'earl'
         *
         * const fn = mockFn().returns(42)
         * fn()
         * expect(fn).toHaveBeenCalledTimes(1)
         * expect(fn).not.toHaveBeenCalledTimes(2)
         * ```
         */
        toHaveBeenCalledTimes(this: Validators<MockFunction<any[], any>>, times: number): void;
    }
}
export declare function toHaveBeenCalledTimes(control: Control, times: number): void;
//# sourceMappingURL=toHaveBeenCalledTimes.d.ts.map