import { Control } from '../../Control.js';
declare module '../../expect.js' {
    interface Validators<T> {
        /**
         * Asserts that a number is greater than the target value.
         *
         * Works for both numbers and bigints.
         *
         * If you want to match a nested value, use the matcher
         * `expect.greaterThan(target)` instead.
         *
         * @param target - The target value to compare to.
         *
         * @example
         * ```ts
         * expect(100_000n).toBeGreaterThan(50_000n)
         *
         * expect(1337n).not.toBeGreaterThan(1337n)
         * expect(0xcafebabe).not.toBeGreaterThan(0xdeadbeef)
         * ```
         */
        toBeGreaterThan(this: Validators<number | bigint>, target: number | bigint): void;
    }
}
export declare function toBeGreaterThan(control: Control, target: number | bigint): void;
//# sourceMappingURL=toBeGreaterThan.d.ts.map